@@ -24,7 +24,7 @@ import numpy as np
 import scipy.io, scipy.sparse
 import click
 
-VERSION = "1.0.6"
+VERSION = "1.0.7"
 
 logging.basicConfig(level=logging.INFO)
 logger = logging.getLogger(__name__)
@@ -653,7 +653,7 @@ def tagcount(sam, out, genemap, output_evidence_table, positional, minevidence,
         genes = pd.Series(index=set(gene_map.values()))
         genes = genes.sort_index()
         # Now genes is assigned to a DataFrame
-        genes = expanded.ix[genes.index]
+        genes = expanded.loc[genes.index]
 
     elif gene_tags:
         expanded.sort_index()
@@ -949,8 +949,8 @@ def sparse(csv, sparse):
     '''
     import pandas as pd
     df = pd.read_csv(csv, index_col=0, header=0)
-    pd.Series(df.index).to_csv(sparse + ".rownames", index=False)
-    pd.Series(df.columns.values).to_csv(sparse + ".colnames", index=False)
+    pd.Series(df.index).to_csv(sparse + ".rownames", index=False, header=False)
+    pd.Series(df.columns.values).to_csv(sparse + ".colnames", index=False, header=False)
     with open(sparse, "w+b") as out_handle:
         scipy.io.mmwrite(out_handle, scipy.sparse.csr_matrix(df))
 
